==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/RulesEngineActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.RulesEngineActionArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * One or more actions that will execute, modifying the request and/or response.
 * @property requestHeaderActions A list of header actions to apply from the request from AFD to the origin.
 * @property responseHeaderActions A list of header actions to apply from the response from AFD to the client.
 * @property routeConfigurationOverride Override the route configuration.
 */
public data class RulesEngineActionArgs(
    public val requestHeaderActions: Output<List<HeaderActionArgs>>? = null,
    public val responseHeaderActions: Output<List<HeaderActionArgs>>? = null,
    public val routeConfigurationOverride:
    Output<Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.RulesEngineActionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.RulesEngineActionArgs =
        com.pulumi.azurenative.network.inputs.RulesEngineActionArgs.builder()
            .requestHeaderActions(
                requestHeaderActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .responseHeaderActions(
                responseHeaderActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .routeConfigurationOverride(
                routeConfigurationOverride?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RulesEngineActionArgs].
 */
@PulumiTagMarker
public class RulesEngineActionArgsBuilder internal constructor() {
    private var requestHeaderActions: Output<List<HeaderActionArgs>>? = null

    private var responseHeaderActions: Output<List<HeaderActionArgs>>? = null

    private var routeConfigurationOverride:
        Output<Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>>? = null

    /**
     * @param value A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("gqdfkcxvviykvyrl")
    public suspend fun requestHeaderActions(`value`: Output<List<HeaderActionArgs>>) {
        this.requestHeaderActions = value
    }

    @JvmName("jthbertpcodxxios")
    public suspend fun requestHeaderActions(vararg values: Output<HeaderActionArgs>) {
        this.requestHeaderActions = Output.all(values.asList())
    }

    /**
     * @param values A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("byulduhojnsvxixq")
    public suspend fun requestHeaderActions(values: List<Output<HeaderActionArgs>>) {
        this.requestHeaderActions = Output.all(values)
    }

    /**
     * @param value A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("ijheyvahemmwjntu")
    public suspend fun responseHeaderActions(`value`: Output<List<HeaderActionArgs>>) {
        this.responseHeaderActions = value
    }

    @JvmName("taguiorsskpryxyb")
    public suspend fun responseHeaderActions(vararg values: Output<HeaderActionArgs>) {
        this.responseHeaderActions = Output.all(values.asList())
    }

    /**
     * @param values A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("bpcblakdfhuecdvb")
    public suspend fun responseHeaderActions(values: List<Output<HeaderActionArgs>>) {
        this.responseHeaderActions = Output.all(values)
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("fgpbtwkscelmpbml")
    public suspend
    fun routeConfigurationOverride(`value`: Output<Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>>) {
        this.routeConfigurationOverride = value
    }

    /**
     * @param value A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("jbqlycppkgpdwgqi")
    public suspend fun requestHeaderActions(`value`: List<HeaderActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("ahjapbrklcgiaxjt")
    public suspend
    fun requestHeaderActions(argument: List<suspend HeaderActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("qcbithjfxumgtnwl")
    public suspend fun requestHeaderActions(
        vararg
        argument: suspend HeaderActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("sfskidklbkrlvjip")
    public suspend fun requestHeaderActions(argument: suspend HeaderActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HeaderActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.requestHeaderActions = mapped
    }

    /**
     * @param values A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("omesvqbocssumdqf")
    public suspend fun requestHeaderActions(vararg values: HeaderActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requestHeaderActions = mapped
    }

    /**
     * @param value A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("kekxpufuurwxuxuc")
    public suspend fun responseHeaderActions(`value`: List<HeaderActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.responseHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("ukmfibxuyaiqwjgt")
    public suspend
    fun responseHeaderActions(argument: List<suspend HeaderActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("uamyyanjdhfcgxks")
    public suspend fun responseHeaderActions(
        vararg
        argument: suspend HeaderActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("adprqstkffchdica")
    public suspend fun responseHeaderActions(argument: suspend HeaderActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HeaderActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.responseHeaderActions = mapped
    }

    /**
     * @param values A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("nlbykiumgvxkkjsd")
    public suspend fun responseHeaderActions(vararg values: HeaderActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.responseHeaderActions = mapped
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("yfldntksjaryppwj")
    public suspend
    fun routeConfigurationOverride(`value`: Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routeConfigurationOverride = mapped
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("dkuyndnpayunjymo")
    public fun routeConfigurationOverride(`value`: ForwardingConfigurationArgs) {
        val toBeMapped = Either.ofLeft<ForwardingConfigurationArgs, RedirectConfigurationArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.routeConfigurationOverride = mapped
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("hekvxjhmmdlecbwe")
    public fun routeConfigurationOverride(`value`: RedirectConfigurationArgs) {
        val toBeMapped = Either.ofRight<ForwardingConfigurationArgs, RedirectConfigurationArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.routeConfigurationOverride = mapped
    }

    internal fun build(): RulesEngineActionArgs = RulesEngineActionArgs(
        requestHeaderActions = requestHeaderActions,
        responseHeaderActions = responseHeaderActions,
        routeConfigurationOverride = routeConfigurationOverride,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/RulesEngineActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.RulesEngineActionArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * One or more actions that will execute, modifying the request and/or response.
 * @property requestHeaderActions A list of header actions to apply from the request from AFD to the origin.
 * @property responseHeaderActions A list of header actions to apply from the response from AFD to the client.
 * @property routeConfigurationOverride Override the route configuration.
 */
public data class RulesEngineActionArgs(
    public val requestHeaderActions: Output<List<HeaderActionArgs>>? = null,
    public val responseHeaderActions: Output<List<HeaderActionArgs>>? = null,
    public val routeConfigurationOverride:
    Output<Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.RulesEngineActionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.RulesEngineActionArgs =
        com.pulumi.azurenative.network.inputs.RulesEngineActionArgs.builder()
            .requestHeaderActions(
                requestHeaderActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .responseHeaderActions(
                responseHeaderActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .routeConfigurationOverride(
                routeConfigurationOverride?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RulesEngineActionArgs].
 */
@PulumiTagMarker
public class RulesEngineActionArgsBuilder internal constructor() {
    private var requestHeaderActions: Output<List<HeaderActionArgs>>? = null

    private var responseHeaderActions: Output<List<HeaderActionArgs>>? = null

    private var routeConfigurationOverride:
        Output<Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>>? = null

    /**
     * @param value A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("divinfijwwxcxbik")
    public suspend fun requestHeaderActions(`value`: Output<List<HeaderActionArgs>>) {
        this.requestHeaderActions = value
    }

    @JvmName("ebjfeqvxmnlyoeuc")
    public suspend fun requestHeaderActions(vararg values: Output<HeaderActionArgs>) {
        this.requestHeaderActions = Output.all(values.asList())
    }

    /**
     * @param values A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("utdovgkhjidmyftr")
    public suspend fun requestHeaderActions(values: List<Output<HeaderActionArgs>>) {
        this.requestHeaderActions = Output.all(values)
    }

    /**
     * @param value A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("luvqpwsaimvwmkpa")
    public suspend fun responseHeaderActions(`value`: Output<List<HeaderActionArgs>>) {
        this.responseHeaderActions = value
    }

    @JvmName("bkxirbjgtubjalqi")
    public suspend fun responseHeaderActions(vararg values: Output<HeaderActionArgs>) {
        this.responseHeaderActions = Output.all(values.asList())
    }

    /**
     * @param values A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("bipayibmjbfqfhaq")
    public suspend fun responseHeaderActions(values: List<Output<HeaderActionArgs>>) {
        this.responseHeaderActions = Output.all(values)
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("aouuhwytrpbxawao")
    public suspend
    fun routeConfigurationOverride(`value`: Output<Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>>) {
        this.routeConfigurationOverride = value
    }

    /**
     * @param value A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("asvhhxfhfphodvsp")
    public suspend fun requestHeaderActions(`value`: List<HeaderActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requestHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("pgvsxelfnmueaajp")
    public suspend
    fun requestHeaderActions(argument: List<suspend HeaderActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("sflevnfiqmlgibxg")
    public suspend fun requestHeaderActions(
        vararg
        argument: suspend HeaderActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.requestHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("bksujnpwwbvjffdd")
    public suspend fun requestHeaderActions(argument: suspend HeaderActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HeaderActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.requestHeaderActions = mapped
    }

    /**
     * @param values A list of header actions to apply from the request from AFD to the origin.
     */
    @JvmName("oyubkjhgokuswvwn")
    public suspend fun requestHeaderActions(vararg values: HeaderActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requestHeaderActions = mapped
    }

    /**
     * @param value A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("kfpvxfuptacwmoxk")
    public suspend fun responseHeaderActions(`value`: List<HeaderActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.responseHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("ojorbmaiigdhirgc")
    public suspend
    fun responseHeaderActions(argument: List<suspend HeaderActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("eayasqmlsxwnmmmp")
    public suspend fun responseHeaderActions(
        vararg
        argument: suspend HeaderActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            HeaderActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.responseHeaderActions = mapped
    }

    /**
     * @param argument A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("jftjjsreurbcwhie")
    public suspend fun responseHeaderActions(argument: suspend HeaderActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(HeaderActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.responseHeaderActions = mapped
    }

    /**
     * @param values A list of header actions to apply from the response from AFD to the client.
     */
    @JvmName("rjakbxidiaaayyma")
    public suspend fun responseHeaderActions(vararg values: HeaderActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.responseHeaderActions = mapped
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("djipgkraunnmhnmg")
    public suspend
    fun routeConfigurationOverride(`value`: Either<ForwardingConfigurationArgs, RedirectConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routeConfigurationOverride = mapped
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("blsoropbxaobklgk")
    public fun routeConfigurationOverride(`value`: ForwardingConfigurationArgs) {
        val toBeMapped = Either.ofLeft<ForwardingConfigurationArgs, RedirectConfigurationArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.routeConfigurationOverride = mapped
    }

    /**
     * @param value Override the route configuration.
     */
    @JvmName("wlfsatenoeurvwss")
    public fun routeConfigurationOverride(`value`: RedirectConfigurationArgs) {
        val toBeMapped = Either.ofRight<ForwardingConfigurationArgs, RedirectConfigurationArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.routeConfigurationOverride = mapped
    }

    internal fun build(): RulesEngineActionArgs = RulesEngineActionArgs(
        requestHeaderActions = requestHeaderActions,
        responseHeaderActions = responseHeaderActions,
        routeConfigurationOverride = routeConfigurationOverride,
    )
}
